%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Funktion synth_init_data() Initialisierung fr Add. Synth.
%
%  Autor: Ulrich Stein, Dept. M+P, HAW Hamburg
%
%  Erzeugt:          15.04.2006
%  Letzte nderung:  24.03.2008
%
%--------------------------------------------------------------------
%
%  Initialisiert die Musik-Datenbasis.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function  synth_data = synth_init_data( synth_data )

    % Variable zur Sicherheit lschen 
    clear synth_data; 
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %
    % Bedeutung der Komponenten des structs synth_data:
    %
    %   oberste Ebene des structs m06_data mit den Komponenten:
    %     version       Version des Musik-Projekts
    %     samplerate    Sample-Rate, fr CDs 44100 / s
    %     frequenz      Test-Frequenz
    %     dauer         Zeitdauer des Tons in s 
    %     intensitaet   Intensitaet des Tons
    %     oberton       Unter-struct mit Daten zu den Obertnen
    %     effekte       Unter-struct mit Daten zu den Effekten
    %     original      Array mit der Original-Amplituden-Funktion
    %     tfeld         Array mit den Zeitpunkten
    %     schwingung    Array mit der Amplituden-Funktion nach Effekten
    %     angelegt      ob bereits Daten definiert sind
    %     filename      Dateiname zum Speichern des Tons
    %     handles       handles-struct des GUI fr Text-Ausgaben, etc.
    %
    synth_data = struct( 'version', 1.1, ...
                       'samplerate', 44100, 'frequenz', 220, ... 
                       'dauer', 3, 'intensitaet', 1, ...
                       'oberton', [], ... 
                       'huellkurve', [], 'hall', [], ...
                       'original', [], ...
                       'tfeld', [], 'schwingung', [], ...
                       'angelegt', 0, 'filename', '',  ... 
                       'handles', []  );                             
                             
    %   Der Unter-struct oberton enthlt folgende Komponenten:  
    %     anzahl        Zahl der Obertne + Grundton
    %     frequenz      Vektor mit relativen Frequenzen der Obertne
    %     intensitaet   Vektor mit relativen Intensitten der Obertne
    %
    synth_data.oberton = struct( 'anzahl', 10, ...
                             'frequenz', [], 'intensitaet', []  ); 
                          
    for( n=1:synth_data.oberton.anzahl )                         
      synth_data.oberton.frequenz(n)    = n;
      synth_data.oberton.intensitaet(n) = 1/n;
    end
    for( n=2:2:synth_data.oberton.anzahl )                         
      synth_data.oberton.intensitaet(n) = 0;
    end
                        
    %   Der Unter-struct huellkurve enthlt folgende Komponenten:  
    %     tattack       Attack-Zeit
    %     hattack       Attack-Hhe
    %     tsustain      Sustain-Zeit 
    %     trelease      Release-Zeit 
    %     hrelease      Release-Hhe
    %
    synth_data.huellkurve = struct( ... 
                            'tattack', 0.1, 'hattack', 1, ...
                            'tsustain', 2.0, ...
                            'trelease', 0.3, 'hrelease', 0.4 );
    
    synth_data.huellkurve.tsustain = synth_data.dauer -...
        synth_data.huellkurve.tattack - synth_data.huellkurve.trelease;
                            
    %   Der Unter-struct hall enthlt folgende Komponenten: 
    %     on            ob Hall eingeschaltet ist
    %     hallzeit      Zeit bis Hall zurckkommt in s
    %     anzahl        Anzahl der Hall-Wiederholungen
    %     amplitude     rel. Amplitide des Halls in Prozent
    %
    synth_data.hall = struct( 'on', 0, ...
                            'hallzeit', 0.1, ...
                            'anzahl', 10, 'amplitude', 15 );  
             
    synth_data.angelegt = 1;
    
return;
